@@ -576,7 +576,7 @@ class Neo4jClient(Client):
 
     # Vertex Container
 
-    def outE(self, _id, label=None):
+    def outE(self, _id, label=None, start=None, limit=None):
         """
         Returns the outgoing edges of the vertex.
 
@@ -590,10 +590,10 @@ class Neo4jClient(Client):
         
         """
         script = self.scripts.get('outE')
-        params = dict(_id=_id,label=label)
+        params = dict(_id=_id,label=label,start=start,limit=limit)
         return self.gremlin(script,params)
 
-    def inE(self, _id, label=None):
+    def inE(self, _id, label=None, start=None, limit=None):
         """
         Returns the incoming edges of the vertex.
 
@@ -607,10 +607,10 @@ class Neo4jClient(Client):
 
         """
         script = self.scripts.get('inE')
-        params = dict(_id=_id,label=label)
+        params = dict(_id=_id,label=label,start=start,limit=limit)
         return self.gremlin(script,params)
 
-    def bothE(self, _id, label=None):
+    def bothE(self, _id, label=None, start=None, limit=None):
         """
         Returns the incoming and outgoing edges of the vertex.
 
@@ -624,10 +624,10 @@ class Neo4jClient(Client):
         
         """
         script = self.scripts.get('bothE')
-        params = dict(_id=_id,label=label)
+        params = dict(_id=_id,label=label,start=start,limit=limit)
         return self.gremlin(script,params)
 
-    def outV(self, _id, label=None):
+    def outV(self, _id, label=None, start=None, limit=None):
         """
         Returns the out-adjacent vertices of the vertex.
 
@@ -641,10 +641,10 @@ class Neo4jClient(Client):
 
         """
         script = self.scripts.get('outV')
-        params = dict(_id=_id,label=label)
+        params = dict(_id=_id,label=label,start=start,limit=limit)
         return self.gremlin(script,params)
         
-    def inV(self, _id, label=None):
+    def inV(self, _id, label=None, start=None, limit=None):
         """
         Returns the in-adjacent vertices of the vertex.
 
@@ -658,10 +658,10 @@ class Neo4jClient(Client):
 
         """
         script = self.scripts.get('inV')
-        params = dict(_id=_id,label=label)
+        params = dict(_id=_id,label=label,start=start,limit=limit)
         return self.gremlin(script,params)
         
-    def bothV(self, _id, label=None):
+    def bothV(self, _id, label=None, start=None, limit=None):
         """
         Returns the incoming- and outgoing-adjacent vertices of the vertex.
 
@@ -675,7 +675,7 @@ class Neo4jClient(Client):
 
         """
         script = self.scripts.get('bothV')
-        params = dict(_id=_id,label=label)
+        params = dict(_id=_id,label=label,start=start,limit=limit)
         return self.gremlin(script,params)
 
     #: Index Proxy - Vertex
